@@ -316,11 +316,7 @@ void VocabularyView::slotEditPaste()
         QStringList lines = clipboard->text().split('\n');
         for (const QString &line : qAsConst(lines)) {
             // split at tabs or semicolon:
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            m_model->appendEntry(new KEduVocExpression(line.split(QRegExp(QStringLiteral("[\t;]")), QString::KeepEmptyParts)));
-#else
-            m_model->appendEntry(new KEduVocExpression(line.split(QRegExp(QStringLiteral("[\t;]")), Qt::KeepEmptyParts)));
-#endif
+            m_model->appendEntry(new KEduVocExpression(line.split(QRegularExpression(QStringLiteral("[\t;]")), Qt::KeepEmptyParts)));
         }
     }
 }
